==> improvements-2.0.1.tar.gz: improvements/src/ImprovementsHelper.php <==
<?php

namespace Drupal\improvements;

use Drupal\contact\MessageInterface;
use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Entity\EntityFormBuilderInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\taxonomy\TermInterface;
use Drupal\taxonomy\TermStorageInterface;

class ImprovementsHelper {

  /**
   * Return term depth.
   */
  public static function getTermDepth(TermInterface $term): int {
    $term_depth = 0;

    while ($term = $term->get('parent')->entity) {
      $term_depth++;
    }

    return $term_depth;
  }

  /**
   * Return term direct children.
   *
   * @return TermInterface[]
   */
  public static function getTermDirectChildren(TermInterface $term): array {
    $term_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term'); /** @var TermStorageInterface $term_storage */
    return $term_storage->getChildren($term);
  }

  /**
   * Return term direct children count.
   */
  public static function getTermDirectChildrenCount(int $term_id): int {
    return \Drupal::entityQuery('taxonomy_term')
      ->condition('parent', $term_id)
      ->count()
      ->execute();
  }

  /**
   * Return all children terms ids regardless of depth.
   *
   * @return integer[]
   */
  public static function getTermAllChildrenIds(string $vocabulary_machine_name, int $term_id): array {
    $term_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term'); /** @var TermStorageInterface $term_storage */
    $all_children_terms = $term_storage->loadTree($vocabulary_machine_name, $term_id); /** @var \stdClass $terms */
    $ids = [];

    foreach ($all_children_terms as $children_term) {
      $ids[] = (int)$children_term->tid;
    }

    return $ids;
  }

  /**
   * Return term direct parents ids.
   */
  public static function getTermDirectParentsIds(int $term_id): array {
    $term = Term::load($term_id);
    $parent_ids = [];

    foreach ($term->get('parent') as $item) {
      if ($target_id = $item->target_id) {
        $parent_ids[] = $target_id;
      }
    }

    return $parent_ids;
  }

  /**
   * Return TRUE if term has children terms.
   */
  public static function termHasChildren(int $term_id): bool {
    return (self::getTermDirectChildrenCount($term_id) > 0);
  }

  /**
   * Return contact form.
   */
  public static function getContactForm(string $contact_form_id): array {
    $contact_message_storage = \Drupal::entityTypeManager()->getStorage('contact_message'); /** @var ContentEntityStorageInterface $contact_message_storage */
    $contact_message = $contact_message_storage->create(['contact_form' => $contact_form_id]); /** @var MessageInterface $contact_message */

    $entity_form_builder = \Drupal::service('entity.form_builder'); /** @var EntityFormBuilderInterface $entity_form_builder */
    $form = $entity_form_builder->getForm($contact_message);
    $form['#cache']['contexts'][] = 'user.permissions';

    return $form;
  }

  /**
   * Return textarea rows count by text length.
   */
  public static function getTextareaRowsCount(string $text, int $min_rows): int {
    $rows = substr_count($text, "\n");
    $rows = min($rows + 1, 28);
    return max($rows, $min_rows);
  }

}

==> improvements-2.0.3.tar.gz: improvements/src/ImprovementsHelper.php <==
<?php

namespace Drupal\improvements;

use Drupal\contact\MessageInterface;
use Drupal\Core\Entity\ContentEntityStorageInterface;
use Drupal\Core\Entity\EntityFormBuilderInterface;

class ImprovementsHelper {

  /**
   * Return contact form.
   */
  public static function getContactForm(string $contact_form_id): array {
    $contact_message_storage = \Drupal::entityTypeManager()->getStorage('contact_message'); /** @var ContentEntityStorageInterface $contact_message_storage */
    $contact_message = $contact_message_storage->create(['contact_form' => $contact_form_id]); /** @var MessageInterface $contact_message */

    $entity_form_builder = \Drupal::service('entity.form_builder'); /** @var EntityFormBuilderInterface $entity_form_builder */
    $form = $entity_form_builder->getForm($contact_message);
    $form['#cache']['contexts'][] = 'user.permissions';

    return $form;
  }

  /**
   * Return textarea rows count by text length.
   */
  public static function getTextareaRowsCount(string $text, int $min_rows): int {
    $rows = substr_count($text, "\n");
    $rows = min($rows + 1, 28);
    return max($rows, $min_rows);
  }

  /**
   * Return e-mail for notifications.
   */
  public static function getEmailForNotifications(): string {
    $site_info = improvements_get_site_information();
    return $site_info['mail_for_notifications'] ?: $site_info['mail'];
  }

  /**
   * Return biild time.
   */
  public static function getBuildTime(): string {
    static $build_time;

    if ($build_time === NULL) {
      $build_time = date(DATE_ATOM, \Drupal::time()->getCurrentTime());
    }

    return $build_time;
  }

}
